@@ -37,7 +37,7 @@ describe 'Basic type mapping' do
 				res.map_types!(btm).values
 			ensure
 				conn&.finish
-			end.take
+			end.value
 
 			expect( vals ).to eq( [
 					[ 1, 'a', 2.0, true, Date.new(2013,6,30) ],
@@ -52,7 +52,7 @@ describe 'Basic type mapping' do
 				res.map_types!(btm).values
 			ensure
 				conn&.finish
-			end.take
+			end.value
 
 			expect( vals ).to eq( [
 					[ 1, 'a', 2.0, true, Date.new(2013,6,30) ],
@@ -275,7 +275,7 @@ describe 'Basic type mapping' do
 			end
 
 			[0].each do |format|
-				it "should do format #{format} JSON conversions", :postgresql_94 do
+				it "should do format #{format} JSON conversions" do
 					['JSON', 'JSONB'].each do |type|
 						res = @conn.exec_params( "SELECT CAST('123' AS #{type}),
 																			CAST('12.3' AS #{type}),
@@ -295,7 +295,7 @@ describe 'Basic type mapping' do
 				end
 			end
 
-			[0].each do |format|
+			[0, 1].each do |format|
 				it "should do format #{format} array type conversions" do
 					res = @conn.exec_params( "SELECT CAST('{1,2,3}' AS INT2[]), CAST('{{1,2},{3,4}}' AS INT2[][]),
 															CAST('{1,2,3}' AS INT4[]),
@@ -397,44 +397,32 @@ describe 'Basic type mapping' do
 		end
 
 		context "with usage of result oids for copy decoder selection" do
-			it "can type cast #copy_data text output with decoder" do
-				@conn.exec( "CREATE TEMP TABLE copytable (t TEXT, i INT, ai INT[])" )
-				@conn.exec( "INSERT INTO copytable VALUES ('a', 123, '{5,4,3}'), ('b', 234, '{2,3}')" )
+			[0, 1].each do |format|
+				it "can type cast #copy_data output in format #{format} with decoder" do
+					@conn.exec( "CREATE TEMP TABLE copytable (t TEXT, i INT, ai INT[], b BYTEA, ts timestamp)" )
+					@conn.exec( "INSERT INTO copytable VALUES ('a', 1234, '{{5,4},{3,2}}', '\\xff000a0d27', '2023-03-17 03:04:05.678912'), ('b', -444, '{2,3}', '\\x202078797a2020', '1990-12-17 15:14:45')" )
 
-				# Retrieve table OIDs per empty result.
-				res = @conn.exec( "SELECT * FROM copytable LIMIT 0" )
-				tm = basic_type_mapping.build_column_map( res )
-				row_decoder = PG::TextDecoder::CopyRow.new(type_map: tm).freeze
+					# Retrieve table OIDs per empty result.
+					res = @conn.exec( "SELECT * FROM copytable LIMIT 0", [], format )
+					tm = basic_type_mapping.build_column_map( res )
+					nsp = format==1 ? PG::BinaryDecoder : PG::TextDecoder
+					row_decoder = nsp::CopyRow.new(type_map: tm).freeze
 
-				rows = []
-				@conn.copy_data( "COPY copytable TO STDOUT", row_decoder ) do |res|
-					while row=@conn.get_copy_data
-						rows << row
+					rows = []
+					@conn.copy_data( "COPY copytable TO STDOUT WITH (FORMAT #{ format==1 ? "binary" : "text" })", row_decoder ) do |res|
+						while row=@conn.get_copy_data
+							rows << row
+						end
 					end
+
+					expect( rows.map{|l| l[0,4] } ).to eq( [['a', 1234, [[5,4],[3,2]], "\xff\x00\n\r'".b], ['b', -444, [2,3], "  xyz  "]] )
+					# For compatibility reason the timestamp in text format is encoded as local time (TimestampWithoutTimeZone) instead of UTC
+					tmeth = format == 1 ? :utc : :local
+					expect( rows[0][4] ).
+						to be_within(0.000001).of( Time.send(tmeth, 2023, 3, 17, 3, 4, 5.678912) )
+					expect( rows[1][4] ).
+						to be_within(0.000001).of( Time.send(tmeth, 1990, 12, 17, 15, 14, 45) )
 				end
-				expect( rows ).to eq( [['a', 123, [5,4,3]], ['b', 234, [2,3]]] )
-			end
-
-			it "can type cast #copy_data binary output with decoder" do
-				@conn.exec( "CREATE TEMP TABLE copytable (b BYTEA, i INT, ts timestamp)" )
-				@conn.exec( "INSERT INTO copytable VALUES ('\\xff000a0d27', 1234, '2023-03-17 03:04:05.678912'), ('\\x202078797a2020', '-444', '1990-12-17 15:14:45')" )
-
-				# Retrieve table OIDs per empty result.
-				res = @conn.exec_params( "SELECT * FROM copytable LIMIT 0", [], 1 )
-				tm = basic_type_mapping.build_column_map( res )
-				row_decoder = PG::BinaryDecoder::CopyRow.new(type_map: tm).freeze
-
-				rows = []
-				@conn.copy_data( "COPY copytable TO STDOUT WITH (FORMAT binary)", row_decoder ) do |res|
-					while row=@conn.get_copy_data
-						rows << row
-					end
-				end
-				expect( rows.map{|l| l[0,2] } ).to eq( [["\xff\x00\n\r'".b, 1234], ["  xyz  ", -444]] )
-				expect( rows[0][2] ).
-					to be_within(0.000001).of( Time.utc(2023, 3, 17, 3, 4, 5.678912) )
-				expect( rows[1][2] ).
-					to be_within(0.000001).of( Time.utc(1990, 12, 17, 15, 14, 45) )
 			end
 		end
 	end
